.dsfr-component[data-v-5511c3b7]{display:contents}.dsfr-component[data-v-5511c3b7] .fr-btn>span{display:contents}.dsfr-component[data-icon-only][data-v-5511c3b7] .fr-btn{padding-inline:.5rem!important}.dsfr-component[data-icon-only][data-v-5511c3b7] .fr-btn iconify-icon{font-size:1.5em}.dsfr-component.dsfr-button-success[data-v-5511c3b7] .fr-btn:not(:disabled):not(:hover):not(:active){background-color:#004000}.dsfr-component.dsfr-button-success[data-v-5511c3b7] .fr-btn{--hover: rgb(0, 115, 0);--active: rgb(0, 120, 0)}.dsfr-component.dsfr-button-warning[data-v-5511c3b7] .fr-btn:not(:disabled):not(:hover):not(:active){background-color:#4a2500}.dsfr-component.dsfr-button-warning[data-v-5511c3b7] .fr-btn{--hover: rgb(132, 66, 0);--active: rgb(138, 69, 0)}.dsfr-component.dsfr-button-danger[data-v-5511c3b7] .fr-btn:not(:disabled):not(:hover):not(:active){background-color:#5a0000}.dsfr-component.dsfr-button-danger[data-v-5511c3b7] .fr-btn{--hover: rgb(160, 0, 0);--active: rgb(169, 0, 0)}
