import{_ as n,u as _,k as m,S as u}from"./StreamlitVue.BzF8oK6q.js";import{d as s,o as a,c as d,a as i,n as l,g as f,b}from"./runtime-dom.esm-bundler.CZSh2bQH.js";/* empty css                               */const B=s({__name:"DsfrBreadcrumb",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(o,{expose:r}){r(),_();const e={props:o,get DsfrBreadcrumb(){return m}};return Object.defineProperty(e,"__isScriptSetup",{enumerable:!1,value:!0}),e}}),S={class:"component"};function x(o,r,t,e,c,p){return a(),d("div",S,[i(e.DsfrBreadcrumb,l(f(e.props.args)),null,16)])}const $=n(B,[["render",x]]),g=s({__name:"DsfrBreadcrumb",setup(o,{expose:r}){r();const t={StreamlitComponent:u,Component:$};return Object.defineProperty(t,"__isScriptSetup",{enumerable:!1,value:!0}),t}});function h(o,r,t,e,c,p){return a(),b(e.StreamlitComponent,{component:e.Component,"client:load":""})}const v=n(g,[["render",h]]);export{v as default};
