.component[data-v-61d47d67] .fr-fieldset{margin-bottom:-.5rem}.component[data-v-61d47d67] .fr-fieldset__legend{padding-bottom:.5rem}.component[data-v-61d47d67] .fr-fieldset__element{margin-bottom:.5rem}
