import{_ as p,u as i,b as m,a as _,S as u}from"./StreamlitVue.BzF8oK6q.js";/* empty css                                  */import{d as l,r as f,p as b,o as d,c as h,a as k,q as C,w as g,m as x,h as y,s as S,t as v,b as V}from"./runtime-dom.esm-bundler.CZSh2bQH.js";/* empty css                               */const D=l({__name:"DsfrCheckbox",props:{args:{},width:{},disabled:{type:Boolean},theme:{}},setup(a,{expose:t}){t(),i();const o=a,e=f(o.args.modelValue??!1),r=b({});o.theme&&(r["--base"]=o.theme.base,r["--primary-color"]=o.theme.primaryColor,r["--background-color"]=o.theme.backgroundColor,r["--secondary-background-color"]=o.theme.secondaryBackgroundColor,r["--text-color"]=o.theme.textColor,r["--font"]=o.theme.font);const n={props:o,checked:e,style:r,onInput:c=>{c.stopPropagation(),e.value=c.currentTarget.checked,_.setComponentValue(e.value)},get DsfrCheckbox(){return m}};return Object.defineProperty(n,"__isScriptSetup",{enumerable:!1,value:!0}),n}});function B(a,t,o,e,r,s){return d(),h("div",{class:"component",style:y(e.style)},[k(e.DsfrCheckbox,x(e.props.args,{disabled:e.props.disabled||e.props.args.disabled,modelValue:e.checked,"onUpdate:modelValue":t[0]||(t[0]=n=>e.checked=n),onInput:e.onInput}),C({_:2},[e.props.args.requiredTip?{name:"required-tip",fn:g(()=>[S(v(e.props.args.requiredTip),1)]),key:"0"}:void 0]),1040,["disabled","modelValue"])],4)}const I=p(D,[["render",B],["__scopeId","data-v-1b8c1c9b"]]),q=l({__name:"DsfrCheckbox",setup(a,{expose:t}){t();const o={StreamlitComponent:u,Component:I};return Object.defineProperty(o,"__isScriptSetup",{enumerable:!1,value:!0}),o}});function P(a,t,o,e,r,s){return d(),V(e.StreamlitComponent,{component:e.Component,"client:load":""})}const O=p(q,[["render",P]]);export{O as default};
